@@ -10,17 +10,17 @@ test_that("we can query actions for a sample project", {
   install("breakfast")
 
   acts <- actions("snapshot", library = renv_paths_library(), project = getwd())
-  expect_true(nrow(acts) == 3)
+  expect_equal(nrow(acts), 3L)
   expect_setequal(acts$Package, c("breakfast", "oatmeal", "toast"))
   expect_true(all(acts$Action == "install"))
 
   # note: empty for non-clean restore as we don't remove packages
   acts <- actions("restore", library = renv_paths_library(), project = getwd())
-  expect_true(nrow(acts) == 0)
+  expect_equal(nrow(acts), 0L)
 
   # now non-empty
   acts <- actions("restore", library = renv_paths_library(), project = getwd(), clean = TRUE)
-  expect_true(nrow(acts) == 3)
+  expect_equal(nrow(acts), 3L)
   expect_setequal(acts$Package, c("breakfast", "oatmeal", "toast"))
   expect_true(all(acts$Action == "remove"))
 
@@ -31,7 +31,7 @@ test_that("we can query actions when no lockfile has yet been generated", {
   init(bare = TRUE)
   install("bread")
   actions <- actions("snapshot")
-  expect_true(nrow(actions) == 1L)
+  expect_equal(nrow(actions), 1L)
 })
 
 test_that("bare usages of actions work as expected", {
@@ -46,7 +46,7 @@ test_that("bare usages of actions work as expected", {
   writeLines("library(breakfast)", con = "deps.R")
   acts <- actions("snapshot")
 
-  expect_true(nrow(acts) == 3)
+  expect_equal(nrow(acts), 3L)
   expect_setequal(acts$Package, c("breakfast", "oatmeal", "toast"))
   expect_true(all(acts$Action == "install"))
 
